/**
 *  @file
 **/

(function ($, Drupal, window, document, cookie) {

  'use strict';
  const AUTH_COOKIE = 'STYXKEY_pelcro_user_auth_token'
  const USER_COOKIE = 'STYXKEY_pelcro_user_id'
  const REFRESH_COOKIE = 'STYXKEY_pelcro_refresh'

  cookie.remove(REFRESH_COOKIE)

  //  A user has logged in through the Pelcro JS SDK
  document.addEventListener("PelcroUserLogin", function (e) {
    cookie.set(AUTH_COOKIE, btoa(e.detail.data.token), { expires: 14 })
    cookie.set(USER_COOKIE, e.detail.data.id)
    let destination = window.location.href
    let url = window.location.protocol + '//' + window.location.hostname + '/pelcro/login/' + btoa(e.detail.data.token) + '?destination=' + destination
    window.location.replace(url)
  });

  // A new user has registered.
  document.addEventListener("PelcroUserRegister", function (e) {
    cookie.set(AUTH_COOKIE, btoa(e.detail.data.token), { expires: 14 })
    cookie.set(USER_COOKIE, e.detail.data.id)
    $.getJSON("/pelcro/register/" + btoa(e.detail.data.token, function (data) {
      if (!data.success) {
        console.log("Error registering new user, message was " + data.message)
      }
    }))
  });

  // A user has bought a new subscription through the Pelcro JS SDK
  document.addEventListener("PelcroSubscriptionCreate", function (e) {
    cookie.set(AUTH_COOKIE, btoa(e.detail.data.token), { expires: 14 })
    cookie.set(USER_COOKIE, e.detail.data.id)
    let destination = window.location.href
    let url = window.location.protocol + '//' + window.location.hostname + '/pelcro/refresh/' + btoa(e.detail.data.token) + '?destination=' + destination
    window.location.replace(url)
  });

  // A user has updated their info in the Pelcro JS SDK
  document.addEventListener("PelcroUserUpdated", function (e) {
    cookie.set(AUTH_COOKIE, btoa(e.detail.data.token), { expires: 14 })
    cookie.set(USER_COOKIE, e.detail.data.id)
    $.getJSON("/pelcro/update/" + btoa(e.detail.data.token, function (data) {
      if (!data.success) {
        console.log("Error updating user, message was " + data.message)
      }
    }))
  });
  // A user has logged out in the Pelcro JS SDK
  document.addEventListener("PelcroUserLogout", function (e) {
    cookie.remove(AUTH_COOKIE)
    cookie.remove(USER_COOKIE)
    let url = window.location.protocol + '//' + window.location.hostname + '/pelcro/logout'
    window.location.assign(url)
  });

  // A user has been loaded in the Pelcro JS SDK
  // document.addEventListener('PelcroUserRefresh', function (e) {
  //  if (!drupalSettings.pelcro.pelcroBypass && e.detail.data.id != drupalSettings.pelcro.pelcroId) {
  //    cookie.set(AUTH_COOKIE, btoa(e.detail.data.token), { expires: 14 })
  //    cookie.set(USER_COOKIE, e.detail.data.id)
  //    refreshPelcroUser()
  // }
  // })

})(jQuery, Drupal, this, this.document, this.Cookies);
