<?php

namespace Drupal\pelcro_auth\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Logger\LoggerChannelInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\pelcro_auth\PelcroConnectorInterface;
use Drupal\externalauth\AuthmapInterface;
use Drupal\externalauth\ExternalAuthInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;

/**
 * Event subscriber to check login status on page load.
 *
 * This subscriber will respond to a kernel request event and compare the user
 * login state to the pelcro authorization cookie.
 */
class RequestSubscriber implements EventSubscriberInterface {

  /**
   * Drupal\pelcro_auth\PelcroConnectorInterface definition.
   *
   * @var \Drupal\pelcro_auth\PelcroConnectorInterface
   */
  protected PelcroConnectorInterface $pelcroAuthConnector;

  /**
   * Drupal\externalauth\AuthmapInterface definition.
   *
   * @var \Drupal\externalauth\AuthmapInterface
   */
  protected AuthmapInterface $externalauthAuthmap;

  /**
   * Drupal\externalauth\ExternalAuthInterface definition.
   *
   * @var \Drupal\externalauth\ExternalAuthInterface
   */
  protected ExternalAuthInterface $externalauthExternalauth;

  /**
   * Drupal\Core\Session\AccountProxyInterface definition.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected AccountProxyInterface $currentUser;

  /**
   * The Pelcro Logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected LoggerChannelInterface $logger;

  /**
   * The pelcro configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $pelcroConfig;

  /**
   * The pelcro configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $pelcroRolemap;

  /**
   * Constructs a new RequestSubscriber object.
   */
  public function __construct(PelcroConnectorInterface $pelcro_auth_connector, AuthmapInterface $externalauth_authmap, ExternalAuthInterface $externalauth_externalauth, AccountProxyInterface $current_user, ConfigFactoryInterface $config_factory, LoggerChannelInterface $logger) {
    $this->pelcroAuthConnector = $pelcro_auth_connector;
    $this->externalauthAuthmap = $externalauth_authmap;
    $this->externalauthExternalauth = $externalauth_externalauth;
    $this->currentUser = $current_user;
    $this->pelcroConfig = $config_factory->get('pelcro_auth.pelcrosettings');
    $this->pelcroRolemap = $config_factory->get('pelcro_auth.pelcrorolemap');
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events['kernel.request'] = ['onKernelRequest', 100];

    return $events;
  }

  /**
   * This method is called when the kernel.request is dispatched.
   *
   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   The dispatched event.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function onKernelRequest(RequestEvent $event) {}

}
